@@ -51,6 +51,13 @@ _S3_OUTPOST_TO_BUCKET_KEY_REGEX = re.compile(
     r'^(?P<bucket>arn:(aws).*:s3-outposts:[a-z\-0-9]+:[0-9]{12}:outpost[/:]'
     r'[a-zA-Z0-9\-]{1,63}[/:]accesspoint[/:][a-zA-Z0-9\-]{1,63})[/:]?(?P<key>.*)$'
 )
+
+_S3_OUTPOST_BUCKET_ARN_TO_BUCKET_KEY_REGEX = re.compile(
+    r'^(?P<bucket>arn:(aws).*:s3-outposts:[a-z\-0-9]+:[0-9]{12}:outpost[/:]'
+    r'[a-zA-Z0-9\-]{1,63}[/:]bucket[/:]'
+    r'[a-zA-Z0-9\-]{1,63})[/:]?(?P<key>.*)$'
+)
+
 _S3_OBJECT_LAMBDA_TO_BUCKET_KEY_REGEX = re.compile(
     r'^(?P<bucket>arn:(aws).*:s3-object-lambda:[a-z\-0-9]+:[0-9]{12}:'
     r'accesspoint[/:][a-zA-Z0-9\-]{1,63})[/:]?(?P<key>.*)$'
@@ -187,11 +194,10 @@ class StablePriorityQueue(queue.Queue):
             return bucket.popleft()
 
 
-def block_s3_object_lambda(s3_path):
-    # AWS CLI s3 commands don't support banner resources only direct API calls
+def block_unsupported_resources(s3_path):
+    # AWS CLI s3 commands don't support object lambdas only direct API calls
     # are available for such resources
-    match = _S3_OBJECT_LAMBDA_TO_BUCKET_KEY_REGEX.match(s3_path)
-    if match:
+    if _S3_OBJECT_LAMBDA_TO_BUCKET_KEY_REGEX.match(s3_path):
         # In AWS CLI v2 we should use
         # awscli.customizations.exceptions.ParamValidationError
         # instead of ValueError
@@ -199,6 +205,13 @@ def block_s3_object_lambda(s3_path):
             's3 commands do not support S3 Object Lambda resources. '
             'Use s3api commands instead.'
         )
+    # AWS S3 API and AWS CLI s3 commands don't support Outpost bucket ARNs
+    # only s3control API supports them so far
+    if _S3_OUTPOST_BUCKET_ARN_TO_BUCKET_KEY_REGEX.match(s3_path):
+        raise ValueError(
+            's3 commands do not support Outpost Bucket ARNs. '
+            'Use s3control commands instead.'
+        )
 
 
 def find_bucket_key(s3_path):
@@ -207,7 +220,7 @@ def find_bucket_key(s3_path):
     the form: bucket/key
     It will return the bucket and the key represented by the s3 path
     """
-    block_s3_object_lambda(s3_path)
+    block_unsupported_resources(s3_path)
     match = _S3_ACCESSPOINT_TO_BUCKET_KEY_REGEX.match(s3_path)
     if match:
         return match.group('bucket'), match.group('key')
